@@ -5,7 +5,7 @@
 %%% Created :  7 May 2006 by Mickael Remond <mremond@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2013   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2015   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -17,10 +17,9 @@
 %%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 %%% General Public License for more details.
 %%%
-%%% You should have received a copy of the GNU General Public License
-%%% along with this program; if not, write to the Free Software
-%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-%%% 02111-1307 USA
+%%% You should have received a copy of the GNU General Public License along
+%%% with this program; if not, write to the Free Software Foundation, Inc.,
+%%% 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 %%%
 %%%-------------------------------------------------------------------
 
@@ -32,6 +31,7 @@
 	 status/0, reopen_log/0,
 	 stop_kindly/2, send_service_message_all_mucs/2,
 	 registered_vhosts/0,
+	 reload_config/0,
 	 %% Erlang
 	 update_list/0, update/1,
 	 %% Accounts
@@ -135,6 +135,11 @@ commands() ->
 			module = ?MODULE, function = registered_vhosts,
 			args = [],
 			result = {vhosts, {list, {vhost, string}}}},
+     #ejabberd_commands{name = reload_config, tags = [server],
+			desc = "Reload ejabberd configuration file into memory",
+			module = ?MODULE, function = reload_config,
+			args = [],
+			result = {res, rescode}},
 
      #ejabberd_commands{name = import_file, tags = [mnesia],
 			desc = "Import user data from jabberd14 spool file",
@@ -253,9 +258,10 @@ reopen_log() ->
 %%% Stop Kindly
 %%%
 
-stop_kindly(DelaySeconds, AnnouncementText) ->
-    Subject = io_lib:format("Server stop in ~p seconds!", [DelaySeconds]),
-    WaitingDesc = io_lib:format("Waiting ~p seconds", [DelaySeconds]),
+stop_kindly(DelaySeconds, AnnouncementTextString) ->
+    Subject = list_to_binary(io_lib:format("Server stop in ~p seconds!", [DelaySeconds])),
+    WaitingDesc = list_to_binary(io_lib:format("Waiting ~p seconds", [DelaySeconds])),
+    AnnouncementText = list_to_binary(AnnouncementTextString),
     Steps = [
 	     {"Stopping ejabberd port listeners",
 	      ejabberd_listener, stop_listeners, []},
@@ -352,6 +358,11 @@ registered_users(Host) ->
 registered_vhosts() ->
 	?MYHOSTS.
 
+reload_config() ->
+    ejabberd_config:reload_file(),
+    acl:start(),
+    shaper:start().
+
 %%%
 %%% Migration management
 %%%
