@@ -139,8 +139,8 @@
          passwd = <<"">>         :: binary(),
          id = 0                  :: non_neg_integer(),
          bind_timer = make_ref() :: reference(),
-	 dict = dict:new()       :: dict(),
-         req_q = queue:new()     :: queue()}).
+	 dict = dict:new()       :: ?TDICT,
+         req_q = queue:new()     :: ?TQUEUE}).
 
 %%%----------------------------------------------------------------------
 %%% API
