@@ -51,12 +51,12 @@
          encoding = <<"">>     :: binary(),
          port = 0              :: inet:port_number(),
          password = <<"">>     :: binary(),
-         queue = queue:new()   :: queue(),
+         queue = queue:new()   :: ?TQUEUE,
          user = #jid{}         :: jid(),
          host = <<"">>         :: binary(),
 	 server = <<"">>       :: binary(),
          nick = <<"">>         :: binary(),
-         channels = dict:new() :: dict(),
+         channels = dict:new() :: ?TDICT,
          nickchannel           :: binary(),
          mod = mod_irc         :: atom(),
 	 inbuf = <<"">>        :: binary(),
@@ -697,9 +697,9 @@ terminate(_Reason, _StateName, FullStateData) ->
 					     <<"Server Connect Failed">>}]},
 				FullStateData}
 			 end,
-    (FullStateData#state.mod):closed_connection(StateData#state.host,
-						StateData#state.user,
-						StateData#state.server),
+    (StateData#state.mod):closed_connection(StateData#state.host,
+                                            StateData#state.user,
+                                            StateData#state.server),
     bounce_messages(<<"Server Connect Failed">>),
     lists:foreach(fun (Chan) ->
 			  Stanza = #xmlel{name = <<"presence">>,
